@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -123,6 +126,42 @@ class CloudDeployAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return CloudDeployClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> CloudDeployTransport:
         """Returns the transport used by the client instance.
@@ -195,6 +234,27 @@ class CloudDeployAsyncClient:
         r"""Lists DeliveryPipelines in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_list_delivery_pipelines():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.ListDeliveryPipelinesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_delivery_pipelines(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.ListDeliveryPipelinesRequest, dict]):
                 The request object. The request object for
@@ -222,7 +282,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -284,6 +344,25 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.DeliveryPipeline:
         r"""Gets details of a single DeliveryPipeline.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_get_delivery_pipeline():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.GetDeliveryPipelineRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_delivery_pipeline(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.GetDeliveryPipelineRequest, dict]):
                 The request object. The request object for
@@ -312,7 +391,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -371,6 +450,31 @@ class CloudDeployAsyncClient:
         r"""Creates a new DeliveryPipeline in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_create_delivery_pipeline():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.CreateDeliveryPipelineRequest(
+                    parent="parent_value",
+                    delivery_pipeline_id="delivery_pipeline_id_value",
+                )
+
+                # Make the request
+                operation = client.create_delivery_pipeline(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.CreateDeliveryPipelineRequest, dict]):
                 The request object. The request object for
@@ -413,7 +517,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, delivery_pipeline, delivery_pipeline_id])
         if request is not None and has_flattened_params:
@@ -473,6 +577,28 @@ class CloudDeployAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single DeliveryPipeline.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_update_delivery_pipeline():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.UpdateDeliveryPipelineRequest(
+                )
+
+                # Make the request
+                operation = client.update_delivery_pipeline(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.UpdateDeliveryPipelineRequest, dict]):
                 The request object. The request object for
@@ -514,7 +640,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([delivery_pipeline, update_mask])
         if request is not None and has_flattened_params:
@@ -573,6 +699,29 @@ class CloudDeployAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single DeliveryPipeline.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_delete_delivery_pipeline():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.DeleteDeliveryPipelineRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_delivery_pipeline(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.DeleteDeliveryPipelineRequest, dict]):
                 The request object. The request object for
@@ -611,7 +760,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -666,6 +815,26 @@ class CloudDeployAsyncClient:
     ) -> pagers.ListTargetsAsyncPager:
         r"""Lists Targets in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_list_targets():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.ListTargetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_targets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.ListTargetsRequest, dict]):
                 The request object. The request object for
@@ -693,7 +862,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -755,6 +924,25 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.Target:
         r"""Gets details of a single Target.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_get_target():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.GetTargetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_target(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.GetTargetRequest, dict]):
                 The request object. The request object for `GetTarget`.
@@ -780,7 +968,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -838,6 +1026,30 @@ class CloudDeployAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Target in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_create_target():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.CreateTargetRequest(
+                    parent="parent_value",
+                    target_id="target_id_value",
+                )
+
+                # Make the request
+                operation = client.create_target(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.CreateTargetRequest, dict]):
                 The request object. The request object for
@@ -879,7 +1091,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, target, target_id])
         if request is not None and has_flattened_params:
@@ -939,6 +1151,28 @@ class CloudDeployAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Target.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_update_target():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.UpdateTargetRequest(
+                )
+
+                # Make the request
+                operation = client.update_target(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.UpdateTargetRequest, dict]):
                 The request object. The request object for
@@ -978,7 +1212,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([target, update_mask])
         if request is not None and has_flattened_params:
@@ -1037,6 +1271,29 @@ class CloudDeployAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Target.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_delete_target():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.DeleteTargetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_target(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.DeleteTargetRequest, dict]):
                 The request object. The request object for
@@ -1075,7 +1332,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1130,6 +1387,26 @@ class CloudDeployAsyncClient:
     ) -> pagers.ListReleasesAsyncPager:
         r"""Lists Releases in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_list_releases():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.ListReleasesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_releases(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.ListReleasesRequest, dict]):
                 The request object. The request object for
@@ -1156,7 +1433,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1218,6 +1495,25 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.Release:
         r"""Gets details of a single Release.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_get_release():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.GetReleaseRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_release(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.GetReleaseRequest, dict]):
                 The request object. The request object for `GetRelease`.
@@ -1243,7 +1539,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1302,6 +1598,31 @@ class CloudDeployAsyncClient:
         r"""Creates a new Release in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_create_release():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.CreateReleaseRequest(
+                    parent="parent_value",
+                    release_id="release_id_value",
+                )
+
+                # Make the request
+                operation = client.create_release(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.CreateReleaseRequest, dict]):
                 The request object. The request object for
@@ -1343,7 +1664,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, release, release_id])
         if request is not None and has_flattened_params:
@@ -1402,6 +1723,26 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.ApproveRolloutResponse:
         r"""Approves a Rollout.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_approve_rollout():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.ApproveRolloutRequest(
+                    name="name_value",
+                    approved=True,
+                )
+
+                # Make the request
+                response = client.approve_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.ApproveRolloutRequest, dict]):
                 The request object. The request object used by
@@ -1426,7 +1767,7 @@ class CloudDeployAsyncClient:
                 The response object from ApproveRollout.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1473,6 +1814,26 @@ class CloudDeployAsyncClient:
     ) -> pagers.ListRolloutsAsyncPager:
         r"""Lists Rollouts in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_list_rollouts():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.ListRolloutsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_rollouts(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.ListRolloutsRequest, dict]):
                 The request object. ListRolloutsRequest is the request
@@ -1500,7 +1861,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1562,6 +1923,25 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.Rollout:
         r"""Gets details of a single Rollout.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_get_rollout():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.GetRolloutRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.GetRolloutRequest, dict]):
                 The request object. GetRolloutRequest is the request
@@ -1588,7 +1968,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1647,6 +2027,35 @@ class CloudDeployAsyncClient:
         r"""Creates a new Rollout in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_create_rollout():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                rollout = deploy_v1.Rollout()
+                rollout.target_id = "target_id_value"
+
+                request = deploy_v1.CreateRolloutRequest(
+                    parent="parent_value",
+                    rollout_id="rollout_id_value",
+                    rollout=rollout,
+                )
+
+                # Make the request
+                operation = client.create_rollout(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.CreateRolloutRequest, dict]):
                 The request object. CreateRolloutRequest is the request
@@ -1688,7 +2097,7 @@ class CloudDeployAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, rollout, rollout_id])
         if request is not None and has_flattened_params:
@@ -1747,6 +2156,25 @@ class CloudDeployAsyncClient:
     ) -> cloud_deploy.Config:
         r"""Gets the configuration for a location.
 
+        .. code-block:: python
+
+            from google.cloud import deploy_v1
+
+            def sample_get_config():
+                # Create a client
+                client = deploy_v1.CloudDeployClient()
+
+                # Initialize request argument(s)
+                request = deploy_v1.GetConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.deploy_v1.types.GetConfigRequest, dict]):
                 The request object. Request to get a configuration.
@@ -1768,7 +2196,7 @@ class CloudDeployAsyncClient:
                 Service-wide configuration.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
